#include <QGuiApplication>
#include <QQmlApplicationEngine>
#include <QDirIterator>
#include <QFontDatabase>
#include <QDebug>


int main(int argc, char *argv[])
{
#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    QGuiApplication app(argc, argv);

    QDirIterator it(":/fonts/");
    while (it.hasNext()) {
        auto id = QFontDatabase::addApplicationFont(it.next());
        auto families = QFontDatabase::applicationFontFamilies(id);
        qDebug() << "Font" << families << "loaded from" << it.filePath();
    }

    QFont font(QStringLiteral("Roboto"));
    app.setFont(font);

    QFontDatabase db;
    auto styles = db.styles("Roboto");
    qDebug() << "Roboto styles:" << styles;

    QQmlApplicationEngine engine;
    const QUrl url(QStringLiteral("qrc:/main.qml"));
    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated,
                     &app, [url](QObject *obj, const QUrl &objUrl) {
        if (!obj && url == objUrl)
            QCoreApplication::exit(-1);
    }, Qt::QueuedConnection);
    engine.load(url);

    return app.exec();
}
